@@ -90,9 +90,6 @@ class ImageManipulations(GObject.GObject):
         logging.debug('name: %s' % name)
         
         if self.appendString:
-            # TODO: If the appendString ends in "/", the images will be called ".jpg" which is a
-            # hidden file in it's own new folder (folder name == the image name).
-            # What should we do about it?
             # Insert the append string and convert the extension to lower case
             n = os.path.splitext(name)
             name = "%s%s%s" % (n[0], self.appendString, n[1].lower())
@@ -107,20 +104,27 @@ class ImageManipulations(GObject.GObject):
         except: pass
         
         # Resize the image using ImageMagick
-        args = ["/usr/bin/convert", fileName, "-resize", self.geometry, newFileName]
-        logging.debug('args: %s' % args)
-        retVal = subprocess.call(args)
-        if retVal != 0:
-            logging.error('error while executing resize command: %d' % retVal)
-            (skip, cancel, retry) = self.resizeDialog.error_resizing(fileName)
-            if retry:
-                # Retry with the same image
-                (skip, cancel, newFileName) = self.resize_one_image(fileName)
+        cmd = "/usr/bin/convert"
+        retry = False
+        if not os.path.exists(cmd):
+            # ImageMagick is probably not installed
+            logging.error("Couldn't locate %s" % cmd)
+            (skip, cancel, retry) = self.resizeDialog.error_resizing(
+                                                dependencyMissing=True)
+        else:
+            args = [cmd, fileName, "-resize", self.geometry, newFileName]
+            logging.debug('args: %s' % args)
+            retVal = subprocess.call(args)
+            if retVal != 0:
+                logging.error('error while executing resize command: %d' % retVal)
+                (skip, cancel, retry) = self.resizeDialog.error_resizing(fileName)
+        if retry:
+            # Retry with the same image
+            (skip, cancel, newFileName) = self.resize_one_image(fileName)
         return (skip, cancel, newFileName)
 
     def pack_images(self):
         """Creates a zip file containing the modified files"""
-        # TODO: Verify that all the files to be zipped are valid files (can be untrue if scale==100%)
         # Generate the name of the zipfile
         dirname = os.path.dirname(self.origFiles[0])
         if not dirname:
@@ -140,6 +144,18 @@ class ImageManipulations(GObject.GObject):
                 break
             i += 1
         zipname = "%s.zip" % zipname[i:]
+        
+        # Make sure the zipfile will not be created in a subdirectory
+        # If that would have been the case, make sure we zip the files
+        # using the name relative to where the zipfile is made, so that the
+        # zipped files' names do not conflict (test with this string to
+        # append: `-resized/yy.jpg`)
+        useRelName = False
+        temp = os.path.basename(zipname)
+        if temp != zipname:
+            zipname = temp
+            useRelName = True
+        
         # Create the final zip file name
         self.zipfile = os.path.join(dirname, zipname)
         
@@ -147,9 +163,13 @@ class ImageManipulations(GObject.GObject):
         zout = zipfile.ZipFile(self.zipfile, "w")
         i = float(0)
         for fname in self.newFiles:
-            # TODO: make sure the name of the images are unique (could not be true if using appendString)
-            # TODO: This will crash if an invalid filename is passed (can be the case with scale==100%)
-            zout.write(fname, os.path.basename(fname), zipfile.ZIP_DEFLATED)
+            if useRelName:
+                # This is the filename relative to where the zipfile is created. 
+                fzname = os.path.relpath(fname, dirname)
+            else:
+                fzname = os.path.basename(fname)
+            #TODO: Check what to do with non-ASCII filenames
+            zout.write(fname, fzname, zipfile.ZIP_DEFLATED)
             i += 1
             percent = i / self.numFiles
             self.resizeDialog.builder.get_object("progress_progressbar").set_text("%s %d%%" % (_("Packing images..."), int(percent * 100)))
