@@ -96,6 +96,13 @@ class NautilusImageManipulatorDialog(Gtk.Dialog):
             if not appendString:
                 self.error_with_parameters(_("Please enter some text to append to the filename."))
                 return
+            if appendString[-1] == os.path.sep:
+                # If the appendString ends in "/", the image would be
+                # called ".EXT", which is a hidden file in it's own folder.
+                self.error_with_parameters(
+                       _("The string to append cannot end in %s" %
+                       os.path.sep))
+                return
             # TODO: Check that the value is valid to be appended to the filename
 
         elif self.builder.get_object("inplace_radiobutton").get_active():
@@ -324,17 +331,24 @@ class NautilusImageManipulatorDialog(Gtk.Dialog):
         response = dialog.run()
         dialog.destroy()
 
-    def error_resizing(self, filename):
+    def error_resizing(self, filename=None, dependencyMissing=False):
         """Displays an error message if ImageMagick returned an error while resizing one image."""
-        (folder, image) = os.path.split(filename)
-        label = Gtk.Label(label=_('The image "%(image)s" could not be resized.\n\nCheck whether you have permission to write to this folder:\n%(folder)s' % {"image": image, "folder": folder}))
+        label = None
+        if filename:
+            (folder, image) = os.path.split(filename)
+            buttons =(_("_Skip"), 0,
+                   Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                   _("_Retry"), 1)
+            label = Gtk.Label(label=_('The image "%(image)s" could not be resized.\n\nCheck whether you have permission to write to this folder:\n%(folder)s' % {"image": image, "folder": folder}))
+        if dependencyMissing:
+            buttons =(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                   _("_Retry"), 1)
+            label = Gtk.Label(label=_("The image conversion program wasn't found on your system.\nHave you installed ImageMagick?"))
         label.set_padding(10, 5)
         dialog = Gtk.Dialog(_("Could not resize image"),
                            self,
                            Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                           (_("_Skip"), 0,
-                           Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
-                           _("_Retry"), 1))
+                           buttons)
         dialog.vbox.pack_start(label, True, True, 0)
         label.show()
         response = dialog.run()
